summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorGregory Nutt <gnutt@nuttx.org>2014-01-24 14:04:07 -0600
committerGregory Nutt <gnutt@nuttx.org>2014-01-24 14:04:07 -0600
commitcafcbeb3a0d16b13048d14fa8ef75cce2a87f738 (patch)
tree8e7a8630ff349b9b8e3795af6973370484eb481d
parent2b4abec1eabbc0a2b8ea96c799ebd18da253c6c0 (diff)
downloadnuttx-cafcbeb3a0d16b13048d14fa8ef75cce2a87f738.tar.gz
nuttx-cafcbeb3a0d16b13048d14fa8ef75cce2a87f738.tar.bz2
nuttx-cafcbeb3a0d16b13048d14fa8ef75cce2a87f738.zip
Rename up_irqbutton() to board_button_irq()
-rw-r--r--apps/examples/buttons/buttons_main.c4
-rw-r--r--nuttx/ChangeLog1
-rw-r--r--nuttx/configs/avr32dev1/src/up_buttons.c16
-rw-r--r--nuttx/configs/cloudctrl/src/up_buttons.c8
-rw-r--r--nuttx/configs/fire-stm32v2/src/up_buttons.c8
-rw-r--r--nuttx/configs/hymini-stm32v/src/up_buttons.c8
-rw-r--r--nuttx/configs/kwikstik-k40/src/up_buttons.c8
-rw-r--r--nuttx/configs/lincoln60/src/up_buttons.c12
-rw-r--r--nuttx/configs/lpc4330-xplorer/src/up_buttons.c12
-rw-r--r--nuttx/configs/olimex-lpc1766stk/src/lpc1766stk_internal.h4
-rw-r--r--nuttx/configs/olimex-lpc1766stk/src/up_buttons.c12
-rw-r--r--nuttx/configs/olimex-stm32-p207/src/up_buttons.c8
-rw-r--r--nuttx/configs/open1788/src/lpc17_buttons.c12
-rw-r--r--nuttx/configs/pcduino-a10/src/a1x_buttons.c6
-rw-r--r--nuttx/configs/sam3u-ek/src/up_buttons.c16
-rw-r--r--nuttx/configs/sam4l-xplained/src/sam_buttons.c6
-rw-r--r--nuttx/configs/sam4s-xplained/src/sam_buttons.c6
-rw-r--r--nuttx/configs/sama5d3x-ek/src/sam_buttons.c6
-rw-r--r--nuttx/configs/shenzhou/src/up_buttons.c8
-rw-r--r--nuttx/configs/spark/src/up_buttons.c8
-rw-r--r--nuttx/configs/stm3210e-eval/src/up_buttons.c8
-rw-r--r--nuttx/configs/stm3210e-eval/src/up_pmbuttons.c2
-rw-r--r--nuttx/configs/stm3220g-eval/src/up_buttons.c8
-rw-r--r--nuttx/configs/stm3240g-eval/src/up_buttons.c8
-rw-r--r--nuttx/configs/stm32f100rc_generic/src/up_buttons.c8
-rw-r--r--nuttx/configs/stm32f3discovery/src/up_buttons.c8
-rw-r--r--nuttx/configs/stm32f429i-disco/src/up_buttons.c8
-rw-r--r--nuttx/configs/stm32f4discovery/src/up_buttons.c8
-rw-r--r--nuttx/configs/stm32f4discovery/src/up_pmbuttons.c2
-rw-r--r--nuttx/configs/stm32ldiscovery/src/stm32_buttons.c8
-rw-r--r--nuttx/configs/stm32vldiscovery/src/stm32_buttons.c8
-rw-r--r--nuttx/configs/sure-pic32mx/src/pic32mx_buttons.c8
-rw-r--r--nuttx/configs/twr-k60n512/src/up_buttons.c8
-rw-r--r--nuttx/configs/ubw32/src/up_buttons.c8
-rw-r--r--nuttx/configs/viewtool-stm32f107/src/stm32_buttons.c8
-rw-r--r--nuttx/configs/zkit-arm-1769/src/up_buttons.c8
-rw-r--r--nuttx/include/nuttx/arch.h6
37 files changed, 146 insertions, 145 deletions
diff --git a/apps/examples/buttons/buttons_main.c b/apps/examples/buttons/buttons_main.c
index 130ec2181..ab17cb5bc 100644
--- a/apps/examples/buttons/buttons_main.c
+++ b/apps/examples/buttons/buttons_main.c
@@ -422,7 +422,7 @@ int buttons_main(int argc, char *argv[])
#ifdef CONFIG_ARCH_IRQBUTTONS
for (i = CONFIG_EXAMPLES_IRQBUTTONS_MIN; i <= CONFIG_EXAMPLES_IRQBUTTONS_MAX; i++)
{
- xcpt_t oldhandler = up_irqbutton(i, g_buttoninfo[BUTTON_INDEX(i)].handler);
+ xcpt_t oldhandler = board_button_irq(i, g_buttoninfo[BUTTON_INDEX(i)].handler);
/* Use lowsyslog() for compatibility with interrrupt handler output. */
@@ -491,7 +491,7 @@ int buttons_main(int argc, char *argv[])
#if defined(CONFIG_ARCH_IRQBUTTONS) && defined(CONFIG_NSH_BUILTIN_APPS)
for (i = CONFIG_EXAMPLES_IRQBUTTONS_MIN; i <= CONFIG_EXAMPLES_IRQBUTTONS_MAX; i++)
{
- (void)up_irqbutton(i, NULL);
+ (void)board_button_irq(i, NULL);
}
#endif
diff --git a/nuttx/ChangeLog b/nuttx/ChangeLog
index 9be2ff96c..77a400545 100644
--- a/nuttx/ChangeLog
+++ b/nuttx/ChangeLog
@@ -6514,4 +6514,5 @@
include/nuttx/arch.h (2014-1024).
* Rename up_buttons() to board_buttons() for the same reason (2014-
1-14).
+ * Rename up_irqbutton() to board_button_irq() (2014-1-24).
diff --git a/nuttx/configs/olimex-lpc1766stk/src/lpc1766stk_internal.h b/nuttx/configs/olimex-lpc1766stk/src/lpc1766stk_internal.h
index 86f65ed9e..561037490 100644
--- a/nuttx/configs/olimex-lpc1766stk/src/lpc1766stk_internal.h
+++ b/nuttx/configs/olimex-lpc1766stk/src/lpc1766stk_internal.h
@@ -144,7 +144,7 @@
* NOTES:
* 1. Pull-ups are not required because the pins are already pulled-up by
* through resistors on the board.
- * 2. All buttons are capable of supporting interrupts if up_irqbutton() is
+ * 2. All buttons are capable of supporting interrupts if board_button_irq() is
* called to attach an interrupt handler. Interrupts are configured to
* occur on both edges.
*/
@@ -170,7 +170,7 @@
* NOTES:
* 1. Pull-ups are not required because the pins are already pulled-up by
* through resistors on the board.
- * 2. All buttons are capable of supporting interrupts if up_irqbutton() is
+ * 2. All buttons are capable of supporting interrupts if board_button_irq() is
* called to attach an interrupt handler. Interrupts are configured to
* occur on both edges.
*/
diff --git a/nuttx/configs/stm3210e-eval/src/up_pmbuttons.c b/nuttx/configs/stm3210e-eval/src/up_pmbuttons.c
index ec01c1e90..6548a55de 100644
--- a/nuttx/configs/stm3210e-eval/src/up_pmbuttons.c
+++ b/nuttx/configs/stm3210e-eval/src/up_pmbuttons.c
@@ -304,7 +304,7 @@ void up_pmbuttons(void)
int i;
for (i = CONFIG_PM_IRQBUTTONS_MIN; i <= CONFIG_PM_IRQBUTTONS_MAX; i++)
{
- xcpt_t oldhandler = up_irqbutton(i, g_buttonhandlers[BUTTON_INDEX(i)]);
+ xcpt_t oldhandler = board_button_irq(i, g_buttonhandlers[BUTTON_INDEX(i)]);
if (oldhandler != NULL)
{
diff --git a/nuttx/configs/stm32f4discovery/src/up_pmbuttons.c b/nuttx/configs/stm32f4discovery/src/up_pmbuttons.c
index 5a7d2443e..ea011c909 100644
--- a/nuttx/configs/stm32f4discovery/src/up_pmbuttons.c
+++ b/nuttx/configs/stm32f4discovery/src/up_pmbuttons.c
@@ -135,7 +135,7 @@ void up_pmbuttons(void)
board_button_initialize();
#ifdef CONFIG_ARCH_IRQBUTTONS
- xcpt_t oldhandler = up_irqbutton(0, button_handler);
+ xcpt_t oldhandler = board_button_irq(0, button_handler);
if (oldhandler != NULL)
{
diff --git a/nuttx/configs/avr32dev1/src/up_buttons.c b/nuttx/configs/avr32dev1/src/up_buttons.c
index 930ed76ea..9c9aafc90 100644
--- a/nuttx/configs/avr32dev1/src/up_buttons.c
+++ b/nuttx/configs/avr32dev1/src/up_buttons.c
@@ -67,16 +67,16 @@
****************************************************************************/
/****************************************************************************
- * Name: up_irqbuttonx
+ * Name: board_button_irqx
*
* Description:
- * This function implements the core of the up_irqbutton() logic.
+ * This function implements the core of the board_button_irq() logic.
*
****************************************************************************/
#if defined(CONFIG_AVR32_GPIOIRQ) && defined(CONFIG_ARCH_IRQBUTTONS) && \
(defined(CONFIG_AVR32DEV_BUTTON1_IRQ) || defined(CONFIG_AVR32DEV_BUTTON2_IRQ))
-static xcpt_t up_irqbuttonx(int irq, xcpt_t irqhandler)
+static xcpt_t board_button_irqx(int irq, xcpt_t irqhandler)
{
xcpt_t oldhandler;
@@ -111,7 +111,7 @@ static xcpt_t up_irqbuttonx(int irq, xcpt_t irqhandler)
* Description:
* board_button_initialize() must be called to initialize button resources.
* After that, board_buttons() may be called to collect the current state of
* all buttons or up_irqbutton() may be called to register button interrupt
* handlers.
*
****************************************************************************/
@@ -145,7 +145,7 @@ uint8_t board_buttons(void)
}
/****************************************************************************
- * Name: up_irqbutton
+ * Name: board_button_irq
*
* Description:
* This function may be called to register an interrupt handler that will
@@ -163,19 +163,19 @@ uint8_t board_buttons(void)
****************************************************************************/
#if defined(CONFIG_AVR32_GPIOIRQ) && defined(CONFIG_ARCH_IRQBUTTONS)
-xcpt_t up_irqbutton(int id, xcpt_t irqhandler)
+xcpt_t board_button_irq(int id, xcpt_t irqhandler)
{
#ifdef CONFIG_AVR32DEV_BUTTON1_IRQ
if (id == BUTTON1)
{
- return up_irqbuttonx(GPIO_BUTTON1_IRQ, irqhandler);
+ return board_button_irqx(GPIO_BUTTON1_IRQ, irqhandler);
}
else
#endif
#ifdef CONFIG_AVR32DEV_BUTTON2_IRQ
if (id == BUTTON2)
{
- return up_irqbuttonx(GPIO_BUTTON2_IRQ, irqhandler);
+ return board_button_irqx(GPIO_BUTTON2_IRQ, irqhandler);
}
else
#endif
@@ -111,7 +111,7 @@ static xcpt_t up_irqbuttonx(int irq, xcpt_t irqhandler)
* board_button_initialize() must be called to initialize button resources.
* After that, board_buttons() may be called to collect the current state of
- * all buttons or up_irqbutton() may be called to register button interrupt
+ * all buttons or board_button_irq() may be called to register button interrupt
* handlers.
*
diff --git a/nuttx/configs/cloudctrl/src/up_buttons.c b/nuttx/configs/cloudctrl/src/up_buttons.c
index 06aa88445..18e4d9057 100644
--- a/nuttx/configs/cloudctrl/src/up_buttons.c
+++ b/nuttx/configs/cloudctrl/src/up_buttons.c
@@ -79,7 +79,7 @@ static const uint16_t g_buttons[NUM_BUTTONS] =
* Description:
* board_button_initialize() must be called to initialize button resources.
* After that, board_buttons() may be called to collect the current state of
* all buttons or up_irqbutton() may be called to register button interrupt
* handlers.
*
****************************************************************************/
@@ -138,7 +138,7 @@ uint8_t board_buttons(void)
* Description:
* board_button_initialize() must be called to initialize button resources.
* After that, board_buttons() may be called to collect the current state of
* all buttons or up_irqbutton() may be called to register button interrupt
* handlers.
*
* After board_button_initialize() has been called, board_buttons() may be
@@ -147,7 +147,7 @@ uint8_t board_buttons(void)
* BUTTON_*_BIT and JOYSTICK_*_BIT definitions in board.h for the meaning
* of each bit.
*
* up_irqbutton() may be called to register an interrupt handler that will
* be called when a button is depressed or released. The ID value is a
* button enumeration value that uniquely identifies a button resource. See
* the
@@ -158,7 +158,7 @@ uint8_t board_buttons(void)
****************************************************************************/
#ifdef CONFIG_ARCH_IRQBUTTONS
-xcpt_t up_irqbutton(int id, xcpt_t irqhandler)
+xcpt_t board_button_irq(int id, xcpt_t irqhandler)
{
xcpt_t oldhandler = NULL;
@@ -79,7 +79,7 @@ static const uint16_t g_buttons[NUM_BUTTONS] =
* board_button_initialize() must be called to initialize button resources.
* After that, board_buttons() may be called to collect the current state of
- * all buttons or up_irqbutton() may be called to register button interrupt
+ * all buttons or board_button_irq() may be called to register button interrupt
* handlers.
*
@@ -138,7 +138,7 @@ uint8_t board_buttons(void)
* board_button_initialize() must be called to initialize button resources.
* After that, board_buttons() may be called to collect the current state of
- * all buttons or up_irqbutton() may be called to register button interrupt
+ * all buttons or board_button_irq() may be called to register button interrupt
* handlers.
*
@@ -147,7 +147,7 @@ uint8_t board_buttons(void)
* of each bit.
*
- * up_irqbutton() may be called to register an interrupt handler that will
+ * board_button_irq() may be called to register an interrupt handler that will
* be called when a button is depressed or released. The ID value is a
* button enumeration value that uniquely identifies a button resource. See
diff --git a/nuttx/configs/fire-stm32v2/src/up_buttons.c b/nuttx/configs/fire-stm32v2/src/up_buttons.c
index 3c93f66e2..b09ee0ad9 100644
--- a/nuttx/configs/fire-stm32v2/src/up_buttons.c
+++ b/nuttx/configs/fire-stm32v2/src/up_buttons.c
@@ -70,7 +70,7 @@
* Description:
* board_button_initialize() must be called to initialize button resources.
* After that, board_buttons() may be called to collect the current state of
* all buttons or up_irqbutton() may be called to register button interrupt
* handlers.
*
****************************************************************************/
@@ -114,7 +114,7 @@ uint8_t board_buttons(void)
* Description:
* board_button_initialize() must be called to initialize button resources.
* After that, board_buttons() may be called to collect the current state of all
* buttons or up_irqbutton() may be called to register button interrupt
* handlers.
*
* After board_button_initialize() has been called, board_buttons() may be
@@ -123,7 +123,7 @@ uint8_t board_buttons(void)
* BUTTON_*_BIT and JOYSTICK_*_BIT definitions in board.h for the meaning
* of each bit.
*
* up_irqbutton() may be called to register an interrupt handler that will
* be called when a button is depressed or released. The ID value is a
* button enumeration value that uniquely identifies a button resource. See
* the BUTTON_* and JOYSTICK_* definitions in board.h for the meaning of
@@ -133,7 +133,7 @@ uint8_t board_buttons(void)
****************************************************************************/
#ifdef CONFIG_ARCH_IRQBUTTONS
-xcpt_t up_irqbutton(int id, xcpt_t irqhandler)
+xcpt_t board_button_irq(int id, xcpt_t irqhandler)
{
uint16_t gpio;
@@ -70,7 +70,7 @@
* board_button_initialize() must be called to initialize button resources.
* After that, board_buttons() may be called to collect the current state of
- * all buttons or up_irqbutton() may be called to register button interrupt
+ * all buttons or board_button_irq() may be called to register button interrupt
* handlers.
*
@@ -114,7 +114,7 @@ uint8_t board_buttons(void)
* board_button_initialize() must be called to initialize button resources.
* After that, board_buttons() may be called to collect the current state of all
- * buttons or up_irqbutton() may be called to register button interrupt
+ * buttons or board_button_irq() may be called to register button interrupt
* handlers.
*
@@ -123,7 +123,7 @@ uint8_t board_buttons(void)
* of each bit.
*
- * up_irqbutton() may be called to register an interrupt handler that will
+ * board_button_irq() may be called to register an interrupt handler that will
* be called when a button is depressed or released. The ID value is a
* button enumeration value that uniquely identifies a button resource. See
diff --git a/nuttx/configs/hymini-stm32v/src/up_buttons.c b/nuttx/configs/hymini-stm32v/src/up_buttons.c
index 76a44a2e9..1175a0fe3 100644
--- a/nuttx/configs/hymini-stm32v/src/up_buttons.c
+++ b/nuttx/configs/hymini-stm32v/src/up_buttons.c
@@ -62,7 +62,7 @@
* Description:
* board_button_initialize() must be called to initialize button resources.
* After that, board_buttons() may be called to collect the current state of
* all buttons or up_irqbutton() may be called to register button interrupt
* handlers.
*
****************************************************************************/
@@ -108,7 +108,7 @@ uint8_t board_buttons(void)
* Description:
* board_button_initialize() must be called to initialize button resources.
* After that, board_buttons() may be called to collect the current state of
* all buttons or up_irqbutton() may be called to register button interrupt
* handlers.
*
* After board_button_initialize() has been called, board_buttons() may be
@@ -117,7 +117,7 @@ uint8_t board_buttons(void)
* BUTTON_*_BIT and JOYSTICK_*_BIT definitions in board.h for the meaning
* of each bit.
*
* up_irqbutton() may be called to register an interrupt handler that will
* be called when a button is depressed or released. The ID value is a
* button enumeration value that uniquely identifies a button resource. See
* the BUTTON_* definitions in board.h for the meaning of enumeration
@@ -127,7 +127,7 @@ uint8_t board_buttons(void)
****************************************************************************/
#ifdef CONFIG_ARCH_IRQBUTTONS
-xcpt_t up_irqbutton(int id, xcpt_t irqhandler)
+xcpt_t board_button_irq(int id, xcpt_t irqhandler)
{
xcpt_t oldhandler = NULL;
uint32_t pinset = GPIO_BTN_KEYA;
@@ -62,7 +62,7 @@
* board_button_initialize() must be called to initialize button resources.
* After that, board_buttons() may be called to collect the current state of
- * all buttons or up_irqbutton() may be called to register button interrupt
+ * all buttons or board_button_irq() may be called to register button interrupt
* handlers.
*
@@ -108,7 +108,7 @@ uint8_t board_buttons(void)
* board_button_initialize() must be called to initialize button resources.
* After that, board_buttons() may be called to collect the current state of
- * all buttons or up_irqbutton() may be called to register button interrupt
+ * all buttons or board_button_irq() may be called to register button interrupt
* handlers.
*
@@ -117,7 +117,7 @@ uint8_t board_buttons(void)
* of each bit.
*
- * up_irqbutton() may be called to register an interrupt handler that will
+ * board_button_irq() may be called to register an interrupt handler that will
* be called when a button is depressed or released. The ID value is a
* button enumeration value that uniquely identifies a button resource. See
diff --git a/nuttx/configs/kwikstik-k40/src/up_buttons.c b/nuttx/configs/kwikstik-k40/src/up_buttons.c
index d86078d23..3477c36cd 100644
--- a/nuttx/configs/kwikstik-k40/src/up_buttons.c
+++ b/nuttx/configs/kwikstik-k40/src/up_buttons.c
@@ -70,7 +70,7 @@
* Description:
* board_button_initialize() must be called to initialize button resources.
* After that, board_buttons() may be called to collect the current state of
* all buttons or up_irqbutton() may be called to register button interrupt
* handlers.
*
****************************************************************************/
@@ -97,7 +97,7 @@ uint8_t board_buttons(void)
* Description:
* board_button_initialize() must be called to initialize button resources.
* After that, board_buttons() may be called to collect the current state of
* all buttons or up_irqbutton() may be called to register button interrupt
* handlers.
*
* After board_button_initialize() has been called, board_buttons() may be
@@ -106,7 +106,7 @@ uint8_t board_buttons(void)
* BUTTON_*_BIT and JOYSTICK_*_BIT definitions in board.h for the meaning
* of each bit.
*
* up_irqbutton() may be called to register an interrupt handler that will
* be called when a button is depressed or released. The ID value is a
* button enumeration value that uniquely identifies a button resource.
* See the BUTTON_* and JOYSTICK_* definitions in board.h for the meaning
@@ -116,7 +116,7 @@ uint8_t board_buttons(void)
****************************************************************************/
#ifdef CONFIG_ARCH_IRQBUTTONS
-xcpt_t up_irqbutton(int id, xcpt_t irqhandler)
+xcpt_t board_button_irq(int id, xcpt_t irqhandler)
{
/* The KwikStik-K40 board has no standard GPIO contact buttons */
@@ -70,7 +70,7 @@
* board_button_initialize() must be called to initialize button resources.
* After that, board_buttons() may be called to collect the current state of
- * all buttons or up_irqbutton() may be called to register button interrupt
+ * all buttons or board_button_irq() may be called to register button interrupt
* handlers.
*
@@ -97,7 +97,7 @@ uint8_t board_buttons(void)
* board_button_initialize() must be called to initialize button resources.
* After that, board_buttons() may be called to collect the current state of
- * all buttons or up_irqbutton() may be called to register button interrupt
+ * all buttons or board_button_irq() may be called to register button interrupt
* handlers.
*
@@ -106,7 +106,7 @@ uint8_t board_buttons(void)
* of each bit.
*
- * up_irqbutton() may be called to register an interrupt handler that will
+ * board_button_irq() may be called to register an interrupt handler that will
* be called when a button is depressed or released. The ID value is a
* button enumeration value that uniquely identifies a button resource.
diff --git a/nuttx/configs/lincoln60/src/up_buttons.c b/nuttx/configs/lincoln60/src/up_buttons.c
index d50a9e59a..0d37b05a4 100644
--- a/nuttx/configs/lincoln60/src/up_buttons.c
+++ b/nuttx/configs/lincoln60/src/up_buttons.c
@@ -99,7 +99,7 @@ static uint8_t g_buttonirq[BOARD_NUM_BUTTONS] =
* Description:
* board_button_initialize() must be called to initialize button resources. After
* that, board_buttons() may be called to collect the current state of all
* buttons or up_irqbutton() may be called to register button interrupt
* handlers.
*
****************************************************************************/
@@ -161,24 +161,24 @@ uint8_t board_buttons(void)
*
* Description:
* board_button_initialize() must be called to initialize button resources. After
* that, up_irqbutton() may be called to register button interrupt handlers.
*
* up_irqbutton() may be called to register an interrupt handler that will
* be called when a button is depressed or released. The ID value is a
* button enumeration value that uniquely identifies a button resource. See the
* BOARD_BUTTON_* and BOARD_JOYSTICK_* definitions in board.h for the meaning
* of enumeration values. The previous interrupt handler address is returned
* (so that it may restored, if so desired).
*
* Note that up_irqbutton() also enables button interrupts. Button
* interrupts will remain enabled after the interrupt handler is attached.
* Interrupts may be disabled (and detached) by calling up_irqbutton with
* irqhandler equal to NULL.
*
****************************************************************************/
#if defined(CONFIG_ARCH_IRQBUTTONS) && defined(CONFIG_GPIO_IRQ)
-xcpt_t up_irqbutton(int id, xcpt_t irqhandler)
+xcpt_t board_button_irq(int id, xcpt_t irqhandler)
{
xcpt_t oldhandler = NULL;
irqstate_t flags;
@@ -99,7 +99,7 @@ static uint8_t g_buttonirq[BOARD_NUM_BUTTONS] =
* board_button_initialize() must be called to initialize button resources. After
* that, board_buttons() may be called to collect the current state of all
- * buttons or up_irqbutton() may be called to register button interrupt
+ * buttons or board_button_irq() may be called to register button interrupt
* handlers.
*
@@ -161,24 +161,24 @@ uint8_t board_buttons(void)
* Description:
* board_button_initialize() must be called to initialize button resources. After
- * that, up_irqbutton() may be called to register button interrupt handlers.
+ * that, board_button_irq() may be called to register button interrupt handlers.
*
@@ -161,24 +161,24 @@ uint8_t board_buttons(void)
*
- * up_irqbutton() may be called to register an interrupt handler that will
+ * board_button_irq() may be called to register an interrupt handler that will
* be called when a button is depressed or released. The ID value is a
* button enumeration value that uniquely identifies a button resource. See the
@@ -161,24 +161,24 @@ uint8_t board_buttons(void)
* (so that it may restored, if so desired).
*
- * Note that up_irqbutton() also enables button interrupts. Button
+ * Note that board_button_irq() also enables button interrupts. Button
* interrupts will remain enabled after the interrupt handler is attached.
@@ -161,24 +161,24 @@ uint8_t board_buttons(void)
* interrupts will remain enabled after the interrupt handler is attached.
- * Interrupts may be disabled (and detached) by calling up_irqbutton with
+ * Interrupts may be disabled (and detached) by calling board_button_irq with
* irqhandler equal to NULL.
*
diff --git a/nuttx/configs/lpc4330-xplorer/src/up_buttons.c b/nuttx/configs/lpc4330-xplorer/src/up_buttons.c
index d9d4882aa..41becbeb8 100644
--- a/nuttx/configs/lpc4330-xplorer/src/up_buttons.c
+++ b/nuttx/configs/lpc4330-xplorer/src/up_buttons.c
@@ -98,7 +98,7 @@ static uint8_t g_buttonirq[BOARD_NUM_BUTTONS] =
* Description:
* board_button_initialize() must be called to initialize button resources. After
* that, board_buttons() may be called to collect the current state of all
* buttons or up_irqbutton() may be called to register button interrupt
* handlers.
*
****************************************************************************/
@@ -160,24 +160,24 @@ uint8_t board_buttons(void)
*
* Description:
* board_button_initialize() must be called to initialize button resources. After
* that, up_irqbutton() may be called to register button interrupt handlers.
*
* up_irqbutton() may be called to register an interrupt handler that will
* be called when a button is depressed or released. The ID value is a
* button enumeration value that uniquely identifies a button resource. See the
* BOARD_BUTTON_* and BOARD_JOYSTICK_* definitions in board.h for the meaning
* of enumeration values. The previous interrupt handler address is returned
* (so that it may restored, if so desired).
*
* Note that up_irqbutton() also enables button interrupts. Button
* interrupts will remain enabled after the interrupt handler is attached.
* Interrupts may be disabled (and detached) by calling up_irqbutton with
* irqhandler equal to NULL.
*
****************************************************************************/
#if defined(CONFIG_ARCH_IRQBUTTONS) && defined(CONFIG_GPIO_IRQ)
-xcpt_t up_irqbutton(int id, xcpt_t irqhandler)
+xcpt_t board_button_irq(int id, xcpt_t irqhandler)
{
xcpt_t oldhandler = NULL;
irqstate_t flags;
@@ -98,7 +98,7 @@ static uint8_t g_buttonirq[BOARD_NUM_BUTTONS] =
* board_button_initialize() must be called to initialize button resources. After
* that, board_buttons() may be called to collect the current state of all
- * buttons or up_irqbutton() may be called to register button interrupt
+ * buttons or board_button_irq() may be called to register button interrupt
* handlers.
*
@@ -160,24 +160,24 @@ uint8_t board_buttons(void)
* Description:
* board_button_initialize() must be called to initialize button resources. After
- * that, up_irqbutton() may be called to register button interrupt handlers.
+ * that, board_button_irq() may be called to register button interrupt handlers.
*
@@ -160,24 +160,24 @@ uint8_t board_buttons(void)
*
- * up_irqbutton() may be called to register an interrupt handler that will
+ * board_button_irq() may be called to register an interrupt handler that will
* be called when a button is depressed or released. The ID value is a
* button enumeration value that uniquely identifies a button resource. See the
@@ -160,24 +160,24 @@ uint8_t board_buttons(void)
* (so that it may restored, if so desired).
*
- * Note that up_irqbutton() also enables button interrupts. Button
+ * Note that board_button_irq() also enables button interrupts. Button
* interrupts will remain enabled after the interrupt handler is attached.
@@ -160,24 +160,24 @@ uint8_t board_buttons(void)
* interrupts will remain enabled after the interrupt handler is attached.
- * Interrupts may be disabled (and detached) by calling up_irqbutton with
+ * Interrupts may be disabled (and detached) by calling board_button_irq with
* irqhandler equal to NULL.
*
diff --git a/nuttx/configs/olimex-lpc1766stk/src/up_buttons.c b/nuttx/configs/olimex-lpc1766stk/src/up_buttons.c
index 1e296c657..49888a521 100644
--- a/nuttx/configs/olimex-lpc1766stk/src/up_buttons.c
+++ b/nuttx/configs/olimex-lpc1766stk/src/up_buttons.c
@@ -102,7 +102,7 @@ static uint8_t g_buttonirq[BOARD_NUM_BUTTONS] =
* Description:
* board_button_initialize() must be called to initialize button resources. After
* that, board_buttons() may be called to collect the current state of all
* buttons or up_irqbutton() may be called to register button interrupt
* handlers.
*
****************************************************************************/
@@ -164,24 +164,24 @@ uint8_t board_buttons(void)
*
* Description:
* board_button_initialize() must be called to initialize button resources. After
* that, up_irqbutton() may be called to register button interrupt handlers.
*
* up_irqbutton() may be called to register an interrupt handler that will
* be called when a button is depressed or released. The ID value is a
* button enumeration value that uniquely identifies a button resource. See the
* BOARD_BUTTON_* and BOARD_JOYSTICK_* definitions in board.h for the meaning
* of enumeration values. The previous interrupt handler address is returned
* (so that it may restored, if so desired).
*
* Note that up_irqbutton() also enables button interrupts. Button
* interrupts will remain enabled after the interrupt handler is attached.
* Interrupts may be disabled (and detached) by calling up_irqbutton with
* irqhandler equal to NULL.
*
****************************************************************************/
#if defined(CONFIG_ARCH_IRQBUTTONS) && defined(CONFIG_GPIO_IRQ)
-xcpt_t up_irqbutton(int id, xcpt_t irqhandler)
+xcpt_t board_button_irq(int id, xcpt_t irqhandler)
{
xcpt_t oldhandler = NULL;
irqstate_t flags;
@@ -102,7 +102,7 @@ static uint8_t g_buttonirq[BOARD_NUM_BUTTONS] =
* board_button_initialize() must be called to initialize button resources. After
* that, board_buttons() may be called to collect the current state of all
- * buttons or up_irqbutton() may be called to register button interrupt
+ * buttons or board_button_irq() may be called to register button interrupt
* handlers.
*
@@ -164,24 +164,24 @@ uint8_t board_buttons(void)
* Description:
* board_button_initialize() must be called to initialize button resources. After
- * that, up_irqbutton() may be called to register button interrupt handlers.
+ * that, board_button_irq() may be called to register button interrupt handlers.
*
@@ -164,24 +164,24 @@ uint8_t board_buttons(void)
*
- * up_irqbutton() may be called to register an interrupt handler that will
+ * board_button_irq() may be called to register an interrupt handler that will
* be called when a button is depressed or released. The ID value is a
* button enumeration value that uniquely identifies a button resource. See the
@@ -164,24 +164,24 @@ uint8_t board_buttons(void)
* (so that it may restored, if so desired).
*
- * Note that up_irqbutton() also enables button interrupts. Button
+ * Note that board_button_irq() also enables button interrupts. Button
* interrupts will remain enabled after the interrupt handler is attached.
@@ -164,24 +164,24 @@ uint8_t board_buttons(void)
* interrupts will remain enabled after the interrupt handler is attached.
- * Interrupts may be disabled (and detached) by calling up_irqbutton with
+ * Interrupts may be disabled (and detached) by calling board_button_irq with
* irqhandler equal to NULL.
*
diff --git a/nuttx/configs/olimex-stm32-p207/src/up_buttons.c b/nuttx/configs/olimex-stm32-p207/src/up_buttons.c
index 843f80be6..390141b06 100644
--- a/nuttx/configs/olimex-stm32-p207/src/up_buttons.c
+++ b/nuttx/configs/olimex-stm32-p207/src/up_buttons.c
@@ -85,7 +85,7 @@ static const uint16_t g_buttons[NUM_BUTTONS] =
* Description:
* board_button_initialize() must be called to initialize button resources. After
* that, board_buttons() may be called to collect the current state of all
* buttons or up_irqbutton() may be called to register button interrupt
* handlers.
*
****************************************************************************/
@@ -158,7 +158,7 @@ uint8_t board_buttons(void)
* Description:
* board_button_initialize() must be called to initialize button resources. After
* that, board_buttons() may be called to collect the current state of all
* buttons or up_irqbutton() may be called to register button interrupt
* handlers.
*
* After board_button_initialize() has been called, board_buttons() may be called to
@@ -166,7 +166,7 @@ uint8_t board_buttons(void)
* with each bit associated with a button. See the BUTTON_*_BIT
* definitions in board.h for the meaning of each bit.
*
* up_irqbutton() may be called to register an interrupt handler that will
* be called when a button is depressed or released. The ID value is a
* button enumeration value that uniquely identifies a button resource. See the
* BUTTON_* definitions in board.h for the meaning of enumeration
@@ -176,7 +176,7 @@ uint8_t board_buttons(void)
************************************************************************************/
#ifdef CONFIG_ARCH_IRQBUTTONS
-xcpt_t up_irqbutton(int id, xcpt_t irqhandler)
+xcpt_t board_button_irq(int id, xcpt_t irqhandler)
{
xcpt_t oldhandler = NULL;
@@ -85,7 +85,7 @@ static const uint16_t g_buttons[NUM_BUTTONS] =
* board_button_initialize() must be called to initialize button resources. After
* that, board_buttons() may be called to collect the current state of all
- * buttons or up_irqbutton() may be called to register button interrupt
+ * buttons or board_button_irq() may be called to register button interrupt
* handlers.
*
@@ -158,7 +158,7 @@ uint8_t board_buttons(void)
* board_button_initialize() must be called to initialize button resources. After
* that, board_buttons() may be called to collect the current state of all
- * buttons or up_irqbutton() may be called to register button interrupt
+ * buttons or board_button_irq() may be called to register button interrupt
* handlers.
*
@@ -166,7 +166,7 @@ uint8_t board_buttons(void)
* definitions in board.h for the meaning of each bit.
*
- * up_irqbutton() may be called to register an interrupt handler that will
+ * board_button_irq() may be called to register an interrupt handler that will
* be called when a button is depressed or released. The ID value is a
* button enumeration value that uniquely identifies a button resource. See the
diff --git a/nuttx/configs/open1788/src/lpc17_buttons.c b/nuttx/configs/open1788/src/lpc17_buttons.c
index 2aa26e9a0..df4ef7b92 100644
--- a/nuttx/configs/open1788/src/lpc17_buttons.c
+++ b/nuttx/configs/open1788/src/lpc17_buttons.c
@@ -120,7 +120,7 @@ static uint8_t g_buttonirq[BOARD_NUM_BUTTONS] =
* Description:
* board_button_initialize() must be called to initialize button resources. After
* that, board_buttons() may be called to collect the current state of all
* buttons or up_irqbutton() may be called to register button interrupt
* handlers.
*
****************************************************************************/
@@ -182,24 +182,24 @@ uint8_t board_buttons(void)
*
* Description:
* board_button_initialize() must be called to initialize button resources. After
* that, up_irqbutton() may be called to register button interrupt handlers.
*
* up_irqbutton() may be called to register an interrupt handler that will
* be called when a button is depressed or released. The ID value is a
* button enumeration value that uniquely identifies a button resource. See the
* BOARD_BUTTON_* and BOARD_JOYSTICK_* definitions in board.h for the meaning
* of enumeration values. The previous interrupt handler address is returned
* (so that it may restored, if so desired).
*
* Note that up_irqbutton() also enables button interrupts. Button
* interrupts will remain enabled after the interrupt handler is attached.
* Interrupts may be disabled (and detached) by calling up_irqbutton with
* irqhandler equal to NULL.
*
****************************************************************************/
#if defined(CONFIG_ARCH_IRQBUTTONS) && defined(CONFIG_GPIO_IRQ)
-xcpt_t up_irqbutton(int id, xcpt_t irqhandler)
+xcpt_t board_button_irq(int id, xcpt_t irqhandler)
{
xcpt_t oldhandler = NULL;
irqstate_t flags;
@@ -120,7 +120,7 @@ static uint8_t g_buttonirq[BOARD_NUM_BUTTONS] =
* board_button_initialize() must be called to initialize button resources. After
* that, board_buttons() may be called to collect the current state of all
- * buttons or up_irqbutton() may be called to register button interrupt
+ * buttons or board_button_irq() may be called to register button interrupt
* handlers.
*
@@ -182,24 +182,24 @@ uint8_t board_buttons(void)
* Description:
* board_button_initialize() must be called to initialize button resources. After
- * that, up_irqbutton() may be called to register button interrupt handlers.
+ * that, board_button_irq() may be called to register button interrupt handlers.
*
@@ -182,24 +182,24 @@ uint8_t board_buttons(void)
*
- * up_irqbutton() may be called to register an interrupt handler that will
+ * board_button_irq() may be called to register an interrupt handler that will
* be called when a button is depressed or released. The ID value is a
* button enumeration value that uniquely identifies a button resource. See the
@@ -182,24 +182,24 @@ uint8_t board_buttons(void)
* (so that it may restored, if so desired).
*
- * Note that up_irqbutton() also enables button interrupts. Button
+ * Note that board_button_irq() also enables button interrupts. Button
* interrupts will remain enabled after the interrupt handler is attached.
@@ -182,24 +182,24 @@ uint8_t board_buttons(void)
* interrupts will remain enabled after the interrupt handler is attached.
- * Interrupts may be disabled (and detached) by calling up_irqbutton with
+ * Interrupts may be disabled (and detached) by calling board_button_irq with
* irqhandler equal to NULL.
*
diff --git a/nuttx/configs/pcduino-a10/src/a1x_buttons.c b/nuttx/configs/pcduino-a10/src/a1x_buttons.c
index 6cae19a93..5ea4359b3 100644
--- a/nuttx/configs/pcduino-a10/src/a1x_buttons.c
+++ b/nuttx/configs/pcduino-a10/src/a1x_buttons.c
@@ -77,7 +77,7 @@ static xcpt_t g_irqbutton[BOARD_NBUTTONS];
* Description:
* board_button_initialize() must be called to initialize button resources. After
* that, board_buttons() may be called to collect the current state of all
* buttons or up_irqbutton() may be called to register button interrupt
* handlers.
*
****************************************************************************/
@@ -104,7 +104,7 @@ uint8_t board_buttons(void)
}
/****************************************************************************
- * Name: up_irqbutton
+ * Name: board_button_irq
*
* Description:
* This function may be called to register an interrupt handler that will
@@ -119,7 +119,7 @@ uint8_t board_buttons(void)
****************************************************************************/
#ifdef CONFIG_ARCH_IRQBUTTONS
-xcpt_t up_irqbutton(int id, xcpt_t irqhandler)
+xcpt_t board_button_irq(int id, xcpt_t irqhandler)
{
xcpt_t oldhandler = NULL;
@@ -77,7 +77,7 @@ static xcpt_t g_irqbutton[BOARD_NBUTTONS];
* board_button_initialize() must be called to initialize button resources. After
* that, board_buttons() may be called to collect the current state of all
- * buttons or up_irqbutton() may be called to register button interrupt
+ * buttons or board_button_irq() may be called to register button interrupt
* handlers.
*
diff --git a/nuttx/configs/sam3u-ek/src/up_buttons.c b/nuttx/configs/sam3u-ek/src/up_buttons.c
index ee8c3be0a..81457162a 100644
--- a/nuttx/configs/sam3u-ek/src/up_buttons.c
+++ b/nuttx/configs/sam3u-ek/src/up_buttons.c
@@ -70,15 +70,15 @@ static xcpt_t g_irqbutton2;
****************************************************************************/
/****************************************************************************
- * Name: up_irqbuttonx
+ * Name: board_button_irqx
*
* Description:
- * This function implements the core of the up_irqbutton() logic.
+ * This function implements the core of the board_button_irq() logic.
*
****************************************************************************/
#if defined(CONFIG_GPIOA_IRQ) && defined(CONFIG_ARCH_IRQBUTTONS)
-static xcpt_t up_irqbuttonx(int irq, xcpt_t irqhandler, xcpt_t *store)
+static xcpt_t board_button_irqx(int irq, xcpt_t irqhandler, xcpt_t *store)
{
xcpt_t oldhandler;
irqstate_t flags;
@@ -117,7 +117,7 @@ static xcpt_t up_irqbuttonx(int irq, xcpt_t irqhandler, xcpt_t *store)
* Description:
* board_button_initialize() must be called to initialize button resources. After
* that, board_buttons() may be called to collect the current state of all
* buttons or up_irqbutton() may be called to register button interrupt
* handlers.
*
****************************************************************************/
@@ -150,7 +150,7 @@ uint8_t board_buttons(void)
}
/****************************************************************************
- * Name: up_irqbutton
+ * Name: board_button_irq
*
* Description:
* This function may be called to register an interrupt handler that will
@@ -168,15 +168,15 @@ uint8_t board_buttons(void)
****************************************************************************/
#if defined(CONFIG_GPIOA_IRQ) && defined(CONFIG_ARCH_IRQBUTTONS)
-xcpt_t up_irqbutton(int id, xcpt_t irqhandler)
+xcpt_t board_button_irq(int id, xcpt_t irqhandler)
{
if (id == BUTTON1)
{
- return up_irqbuttonx(IRQ_BUTTON1, irqhandler, &g_irqbutton1);
+ return board_button_irqx(IRQ_BUTTON1, irqhandler, &g_irqbutton1);
}
else if (id == BUTTON2)
{
- return up_irqbuttonx(IRQ_BUTTON2, irqhandler, &g_irqbutton2);
+ return board_button_irqx(IRQ_BUTTON2, irqhandler, &g_irqbutton2);
}
else
{
@@ -117,7 +117,7 @@ static xcpt_t up_irqbuttonx(int irq, xcpt_t irqhandler, xcpt_t *store)
* board_button_initialize() must be called to initialize button resources. After
* that, board_buttons() may be called to collect the current state of all
- * buttons or up_irqbutton() may be called to register button interrupt
+ * buttons or board_button_irq() may be called to register button interrupt
* handlers.
*
diff --git a/nuttx/configs/sam4l-xplained/src/sam_buttons.c b/nuttx/configs/sam4l-xplained/src/sam_buttons.c
index 450c38a3e..e06f476fc 100644
--- a/nuttx/configs/sam4l-xplained/src/sam_buttons.c
+++ b/nuttx/configs/sam4l-xplained/src/sam_buttons.c
@@ -78,7 +78,7 @@ static xcpt_t g_irqsw0;
* Description:
* board_button_initialize() must be called to initialize button resources. After
* that, board_buttons() may be called to collect the current state of all
* buttons or up_irqbutton() may be called to register button interrupt
* handlers.
*
****************************************************************************/
@@ -105,7 +105,7 @@ uint8_t board_buttons(void)
}
/****************************************************************************
- * Name: up_irqbutton
+ * Name: board_button_irq
*
* Description:
* This function may be called to register an interrupt handler that will
@@ -123,7 +123,7 @@ uint8_t board_buttons(void)
****************************************************************************/
#if defined(CONFIG_GPIOA_IRQ) && defined(CONFIG_ARCH_IRQBUTTONS)
-xcpt_t up_irqbutton(int id, xcpt_t irqhandler)
+xcpt_t board_button_irq(int id, xcpt_t irqhandler)
{
xcpt_t oldhandler = NULL;
@@ -78,7 +78,7 @@ static xcpt_t g_irqsw0;
* board_button_initialize() must be called to initialize button resources. After
* that, board_buttons() may be called to collect the current state of all
- * buttons or up_irqbutton() may be called to register button interrupt
+ * buttons or board_button_irq() may be called to register button interrupt
* handlers.
*
diff --git a/nuttx/configs/sam4s-xplained/src/sam_buttons.c b/nuttx/configs/sam4s-xplained/src/sam_buttons.c
index 855c2b00f..f072440fc 100644
--- a/nuttx/configs/sam4s-xplained/src/sam_buttons.c
+++ b/nuttx/configs/sam4s-xplained/src/sam_buttons.c
@@ -76,7 +76,7 @@ static xcpt_t g_irqbp2;
* Description:
* board_button_initialize() must be called to initialize button resources. After
* that, board_buttons() may be called to collect the current state of all
* buttons or up_irqbutton() may be called to register button interrupt
* handlers.
*
****************************************************************************/
@@ -103,7 +103,7 @@ uint8_t board_buttons(void)
}
/****************************************************************************
- * Name: up_irqbutton
+ * Name: board_button_irq
*
* Description:
* This function may be called to register an interrupt handler that will
@@ -121,7 +121,7 @@ uint8_t board_buttons(void)
****************************************************************************/
#if defined(CONFIG_GPIOA_IRQ) && defined(CONFIG_ARCH_IRQBUTTONS)
-xcpt_t up_irqbutton(int id, xcpt_t irqhandler)
+xcpt_t board_button_irq(int id, xcpt_t irqhandler)
{
xcpt_t oldhandler = NULL;
@@ -76,7 +76,7 @@ static xcpt_t g_irqbp2;
* board_button_initialize() must be called to initialize button resources. After
* that, board_buttons() may be called to collect the current state of all
- * buttons or up_irqbutton() may be called to register button interrupt
+ * buttons or board_button_irq() may be called to register button interrupt
* handlers.
*
diff --git a/nuttx/configs/sama5d3x-ek/src/sam_buttons.c b/nuttx/configs/sama5d3x-ek/src/sam_buttons.c
index 89d4b51bc..9d8afcfba 100644
--- a/nuttx/configs/sama5d3x-ek/src/sam_buttons.c
+++ b/nuttx/configs/sama5d3x-ek/src/sam_buttons.c
@@ -93,7 +93,7 @@ static xcpt_t g_irquser1;
* Description:
* board_button_initialize() must be called to initialize button resources. After
* that, board_buttons() may be called to collect the current state of all
* buttons or up_irqbutton() may be called to register button interrupt
* handlers.
*
****************************************************************************/
@@ -120,7 +120,7 @@ uint8_t board_buttons(void)
}
/****************************************************************************
- * Name: up_irqbutton
+ * Name: board_button_irq
*
* Description:
* This function may be called to register an interrupt handler that will
@@ -136,7 +136,7 @@ uint8_t board_buttons(void)
****************************************************************************/
#if defined(CONFIG_SAMA5_PIOE_IRQ) && defined(CONFIG_ARCH_IRQBUTTONS)
-xcpt_t up_irqbutton(int id, xcpt_t irqhandler)
+xcpt_t board_button_irq(int id, xcpt_t irqhandler)
{
xcpt_t oldhandler = NULL;
@@ -93,7 +93,7 @@ static xcpt_t g_irquser1;
* board_button_initialize() must be called to initialize button resources. After
* that, board_buttons() may be called to collect the current state of all
- * buttons or up_irqbutton() may be called to register button interrupt
+ * buttons or board_button_irq() may be called to register button interrupt
* handlers.
*
diff --git a/nuttx/configs/shenzhou/src/up_buttons.c b/nuttx/configs/shenzhou/src/up_buttons.c
index 7dffcd254..7d4a7f04e 100644
--- a/nuttx/configs/shenzhou/src/up_buttons.c
+++ b/nuttx/configs/shenzhou/src/up_buttons.c
@@ -78,7 +78,7 @@ static const uint16_t g_buttons[NUM_BUTTONS] =
* Description:
* board_button_initialize() must be called to initialize button resources. After
* that, board_buttons() may be called to collect the current state of all
* buttons or up_irqbutton() may be called to register button interrupt
* handlers.
*
****************************************************************************/
@@ -137,7 +137,7 @@ uint8_t board_buttons(void)
* Description:
* board_button_initialize() must be called to initialize button resources. After
* that, board_buttons() may be called to collect the current state of all
* buttons or up_irqbutton() may be called to register button interrupt
* handlers.
*
* After board_button_initialize() has been called, board_buttons() may be called to
@@ -145,7 +145,7 @@ uint8_t board_buttons(void)
* with each bit associated with a button. See the BUTTON_*_BIT and JOYSTICK_*_BIT
* definitions in board.h for the meaning of each bit.
*
* up_irqbutton() may be called to register an interrupt handler that will
* be called when a button is depressed or released. The ID value is a
* button enumeration value that uniquely identifies a button resource. See the
* BUTTON_* and JOYSTICK_* definitions in board.h for the meaning of enumeration
@@ -155,7 +155,7 @@ uint8_t board_buttons(void)
************************************************************************************/
#ifdef CONFIG_ARCH_IRQBUTTONS
-xcpt_t up_irqbutton(int id, xcpt_t irqhandler)
+xcpt_t board_button_irq(int id, xcpt_t irqhandler)
{
xcpt_t oldhandler = NULL;
@@ -78,7 +78,7 @@ static const uint16_t g_buttons[NUM_BUTTONS] =
* board_button_initialize() must be called to initialize button resources. After
* that, board_buttons() may be called to collect the current state of all
- * buttons or up_irqbutton() may be called to register button interrupt
+ * buttons or board_button_irq() may be called to register button interrupt
* handlers.
*
@@ -137,7 +137,7 @@ uint8_t board_buttons(void)
* board_button_initialize() must be called to initialize button resources. After
* that, board_buttons() may be called to collect the current state of all
- * buttons or up_irqbutton() may be called to register button interrupt
+ * buttons or board_button_irq() may be called to register button interrupt
* handlers.
*
@@ -145,7 +145,7 @@ uint8_t board_buttons(void)
* definitions in board.h for the meaning of each bit.
*
- * up_irqbutton() may be called to register an interrupt handler that will
+ * board_button_irq() may be called to register an interrupt handler that will
* be called when a button is depressed or released. The ID value is a
* button enumeration value that uniquely identifies a button resource. See the
diff --git a/nuttx/configs/spark/src/up_buttons.c b/nuttx/configs/spark/src/up_buttons.c
index 410cf052c..bdcaecb72 100644
--- a/nuttx/configs/spark/src/up_buttons.c
+++ b/nuttx/configs/spark/src/up_buttons.c
@@ -70,7 +70,7 @@
* Description:
* board_button_initialize() must be called to initialize button resources. After
* that, board_buttons() may be called to collect the current state of all
* buttons or up_irqbutton() may be called to register button interrupt
* handlers.
*
****************************************************************************/
@@ -101,7 +101,7 @@ uint8_t board_buttons(void)
* Description:
* board_button_initialize() must be called to initialize button resources. After
* that, board_buttons() may be called to collect the current state of all
* buttons or up_irqbutton() may be called to register button interrupt
* handlers.
*
* After board_button_initialize() has been called, board_buttons() may be called to
@@ -109,7 +109,7 @@ uint8_t board_buttons(void)
* with each bit associated with a button. See the BUTTON_*_BIT
* definitions in board.h for the meaning of each bit.
*
* up_irqbutton() may be called to register an interrupt handler that will
* be called when a button is depressed or released. The ID value is a
* button enumeration value that uniquely identifies a button resource. See the
* BUTTON_* definitions in board.h for the meaning of enumeration
@@ -119,7 +119,7 @@ uint8_t board_buttons(void)
************************************************************************************/
#ifdef CONFIG_ARCH_IRQBUTTONS
-xcpt_t up_irqbutton(int id, xcpt_t irqhandler)
+xcpt_t board_button_irq(int id, xcpt_t irqhandler)
{
xcpt_t oldhandler = NULL;
@@ -70,7 +70,7 @@
* board_button_initialize() must be called to initialize button resources. After
* that, board_buttons() may be called to collect the current state of all
- * buttons or up_irqbutton() may be called to register button interrupt
+ * buttons or board_button_irq() may be called to register button interrupt
* handlers.
*
@@ -101,7 +101,7 @@ uint8_t board_buttons(void)
* board_button_initialize() must be called to initialize button resources. After
* that, board_buttons() may be called to collect the current state of all
- * buttons or up_irqbutton() may be called to register button interrupt
+ * buttons or board_button_irq() may be called to register button interrupt
* handlers.
*
@@ -109,7 +109,7 @@ uint8_t board_buttons(void)
* definitions in board.h for the meaning of each bit.
*
- * up_irqbutton() may be called to register an interrupt handler that will
+ * board_button_irq() may be called to register an interrupt handler that will
* be called when a button is depressed or released. The ID value is a
* button enumeration value that uniquely identifies a button resource. See the
diff --git a/nuttx/configs/stm3210e-eval/src/up_buttons.c b/nuttx/configs/stm3210e-eval/src/up_buttons.c
index efc73eb13..245fe832c 100644
--- a/nuttx/configs/stm3210e-eval/src/up_buttons.c
+++ b/nuttx/configs/stm3210e-eval/src/up_buttons.c
@@ -79,7 +79,7 @@ static const uint16_t g_buttons[NUM_BUTTONS] =
* Description:
* board_button_initialize() must be called to initialize button resources. After
* that, board_buttons() may be called to collect the current state of all
* buttons or up_irqbutton() may be called to register button interrupt
* handlers.
*
****************************************************************************/
@@ -138,7 +138,7 @@ uint8_t board_buttons(void)
* Description:
* board_button_initialize() must be called to initialize button resources. After
* that, board_buttons() may be called to collect the current state of all
* buttons or up_irqbutton() may be called to register button interrupt
* handlers.
*
* After board_button_initialize() has been called, board_buttons() may be called to
@@ -146,7 +146,7 @@ uint8_t board_buttons(void)
* with each bit associated with a button. See the BUTTON_*_BIT and JOYSTICK_*_BIT
* definitions in board.h for the meaning of each bit.
*
* up_irqbutton() may be called to register an interrupt handler that will
* be called when a button is depressed or released. The ID value is a
* button enumeration value that uniquely identifies a button resource. See the
* BUTTON_* and JOYSTICK_* definitions in board.h for the meaning of enumeration
@@ -156,7 +156,7 @@ uint8_t board_buttons(void)
************************************************************************************/
#ifdef CONFIG_ARCH_IRQBUTTONS
-xcpt_t up_irqbutton(int id, xcpt_t irqhandler)
+xcpt_t board_button_irq(int id, xcpt_t irqhandler)
{
xcpt_t oldhandler = NULL;
@@ -79,7 +79,7 @@ static const uint16_t g_buttons[NUM_BUTTONS] =
* board_button_initialize() must be called to initialize button resources. After
* that, board_buttons() may be called to collect the current state of all
- * buttons or up_irqbutton() may be called to register button interrupt
+ * buttons or board_button_irq() may be called to register button interrupt
* handlers.
*
@@ -138,7 +138,7 @@ uint8_t board_buttons(void)
* board_button_initialize() must be called to initialize button resources. After
* that, board_buttons() may be called to collect the current state of all
- * buttons or up_irqbutton() may be called to register button interrupt
+ * buttons or board_button_irq() may be called to register button interrupt
* handlers.
*
@@ -146,7 +146,7 @@ uint8_t board_buttons(void)
* definitions in board.h for the meaning of each bit.
*
- * up_irqbutton() may be called to register an interrupt handler that will
+ * board_button_irq() may be called to register an interrupt handler that will
* be called when a button is depressed or released. The ID value is a
* button enumeration value that uniquely identifies a button resource. See the
diff --git a/nuttx/configs/stm3220g-eval/src/up_buttons.c b/nuttx/configs/stm3220g-eval/src/up_buttons.c
index 3ae268cad..091bb6216 100644
--- a/nuttx/configs/stm3220g-eval/src/up_buttons.c
+++ b/nuttx/configs/stm3220g-eval/src/up_buttons.c
@@ -79,7 +79,7 @@ static const uint16_t g_buttons[NUM_BUTTONS] =
* Description:
* board_button_initialize() must be called to initialize button resources. After
* that, board_buttons() may be called to collect the current state of all
* buttons or up_irqbutton() may be called to register button interrupt
* handlers.
*
****************************************************************************/
@@ -138,7 +138,7 @@ uint8_t board_buttons(void)
* Description:
* board_button_initialize() must be called to initialize button resources. After
* that, board_buttons() may be called to collect the current state of all
* buttons or up_irqbutton() may be called to register button interrupt
* handlers.
*
* After board_button_initialize() has been called, board_buttons() may be called to
@@ -146,7 +146,7 @@ uint8_t board_buttons(void)
* with each bit associated with a button. See the BUTTON_*_BIT
* definitions in board.h for the meaning of each bit.
*
* up_irqbutton() may be called to register an interrupt handler that will
* be called when a button is depressed or released. The ID value is a
* button enumeration value that uniquely identifies a button resource. See the
* BUTTON_* definitions in board.h for the meaning of enumeration
@@ -156,7 +156,7 @@ uint8_t board_buttons(void)
************************************************************************************/
#ifdef CONFIG_ARCH_IRQBUTTONS
-xcpt_t up_irqbutton(int id, xcpt_t irqhandler)
+xcpt_t board_button_irq(int id, xcpt_t irqhandler)
{
xcpt_t oldhandler = NULL;
@@ -79,7 +79,7 @@ static const uint16_t g_buttons[NUM_BUTTONS] =
* board_button_initialize() must be called to initialize button resources. After
* that, board_buttons() may be called to collect the current state of all
- * buttons or up_irqbutton() may be called to register button interrupt
+ * buttons or board_button_irq() may be called to register button interrupt
* handlers.
*
@@ -138,7 +138,7 @@ uint8_t board_buttons(void)
* board_button_initialize() must be called to initialize button resources. After
* that, board_buttons() may be called to collect the current state of all
- * buttons or up_irqbutton() may be called to register button interrupt
+ * buttons or board_button_irq() may be called to register button interrupt
* handlers.
*
@@ -146,7 +146,7 @@ uint8_t board_buttons(void)
* definitions in board.h for the meaning of each bit.
*
- * up_irqbutton() may be called to register an interrupt handler that will
+ * board_button_irq() may be called to register an interrupt handler that will
* be called when a button is depressed or released. The ID value is a
* button enumeration value that uniquely identifies a button resource. See the
diff --git a/nuttx/configs/stm3240g-eval/src/up_buttons.c b/nuttx/configs/stm3240g-eval/src/up_buttons.c
index 3433014af..253c31d55 100644
--- a/nuttx/configs/stm3240g-eval/src/up_buttons.c
+++ b/nuttx/configs/stm3240g-eval/src/up_buttons.c
@@ -79,7 +79,7 @@ static const uint16_t g_buttons[NUM_BUTTONS] =
* Description:
* board_button_initialize() must be called to initialize button resources. After
* that, board_buttons() may be called to collect the current state of all
* buttons or up_irqbutton() may be called to register button interrupt
* handlers.
*
****************************************************************************/
@@ -138,7 +138,7 @@ uint8_t board_buttons(void)
* Description:
* board_button_initialize() must be called to initialize button resources. After
* that, board_buttons() may be called to collect the current state of all
* buttons or up_irqbutton() may be called to register button interrupt
* handlers.
*
* After board_button_initialize() has been called, board_buttons() may be called to
@@ -146,7 +146,7 @@ uint8_t board_buttons(void)
* with each bit associated with a button. See the BUTTON_*_BIT
* definitions in board.h for the meaning of each bit.
*
* up_irqbutton() may be called to register an interrupt handler that will
* be called when a button is depressed or released. The ID value is a
* button enumeration value that uniquely identifies a button resource. See the
* BUTTON_* definitions in board.h for the meaning of enumeration
@@ -156,7 +156,7 @@ uint8_t board_buttons(void)
************************************************************************************/
#ifdef CONFIG_ARCH_IRQBUTTONS
-xcpt_t up_irqbutton(int id, xcpt_t irqhandler)
+xcpt_t board_button_irq(int id, xcpt_t irqhandler)
{
xcpt_t oldhandler = NULL;
@@ -79,7 +79,7 @@ static const uint16_t g_buttons[NUM_BUTTONS] =
* board_button_initialize() must be called to initialize button resources. After
* that, board_buttons() may be called to collect the current state of all
- * buttons or up_irqbutton() may be called to register button interrupt
+ * buttons or board_button_irq() may be called to register button interrupt
* handlers.
*
@@ -138,7 +138,7 @@ uint8_t board_buttons(void)
* board_button_initialize() must be called to initialize button resources. After
* that, board_buttons() may be called to collect the current state of all
- * buttons or up_irqbutton() may be called to register button interrupt
+ * buttons or board_button_irq() may be called to register button interrupt
* handlers.
*
@@ -146,7 +146,7 @@ uint8_t board_buttons(void)
* definitions in board.h for the meaning of each bit.
*
- * up_irqbutton() may be called to register an interrupt handler that will
+ * board_button_irq() may be called to register an interrupt handler that will
* be called when a button is depressed or released. The ID value is a
* button enumeration value that uniquely identifies a button resource. See the
diff --git a/nuttx/configs/stm32f100rc_generic/src/up_buttons.c b/nuttx/configs/stm32f100rc_generic/src/up_buttons.c
index 0716b4329..b05b7a1d5 100644
--- a/nuttx/configs/stm32f100rc_generic/src/up_buttons.c
+++ b/nuttx/configs/stm32f100rc_generic/src/up_buttons.c
@@ -59,7 +59,7 @@
* Description:
* board_button_initialize() must be called to initialize button resources. After
* that, board_buttons() may be called to collect the current state of all
* buttons or up_irqbutton() may be called to register button interrupt
* handlers.
*
****************************************************************************/
@@ -88,7 +88,7 @@ uint8_t board_buttons(void)
* Description:
* board_button_initialize() must be called to initialize button resources. After
* that, board_buttons() may be called to collect the current state of all
* buttons or up_irqbutton() may be called to register button interrupt
* handlers.
*
* After board_button_initialize() has been called, board_buttons() may be called to
@@ -96,7 +96,7 @@ uint8_t board_buttons(void)
* with each bit associated with a button. See the BUTTON_*_BIT and JOYSTICK_*_BIT
* definitions in board.h for the meaning of each bit.
*
* up_irqbutton() may be called to register an interrupt handler that will
* be called when a button is depressed or released. The ID value is a
* button enumeration value that uniquely identifies a button resource. See the
* BUTTON_* and JOYSTICK_* definitions in board.h for the meaning of enumeration
@@ -106,7 +106,7 @@ uint8_t board_buttons(void)
************************************************************************************/
#ifdef CONFIG_ARCH_IRQBUTTONS
-xcpt_t up_irqbutton(int id, xcpt_t irqhandler)
+xcpt_t board_button_irq(int id, xcpt_t irqhandler)
{
xcpt_t oldhandler = NULL;
@@ -59,7 +59,7 @@
* board_button_initialize() must be called to initialize button resources. After
* that, board_buttons() may be called to collect the current state of all
- * buttons or up_irqbutton() may be called to register button interrupt
+ * buttons or board_button_irq() may be called to register button interrupt
* handlers.
*
@@ -88,7 +88,7 @@ uint8_t board_buttons(void)
* board_button_initialize() must be called to initialize button resources. After
* that, board_buttons() may be called to collect the current state of all
- * buttons or up_irqbutton() may be called to register button interrupt
+ * buttons or board_button_irq() may be called to register button interrupt
* handlers.
*
@@ -96,7 +96,7 @@ uint8_t board_buttons(void)
* definitions in board.h for the meaning of each bit.
*
- * up_irqbutton() may be called to register an interrupt handler that will
+ * board_button_irq() may be called to register an interrupt handler that will
* be called when a button is depressed or released. The ID value is a
* button enumeration value that uniquely identifies a button resource. See the
diff --git a/nuttx/configs/stm32f3discovery/src/up_buttons.c b/nuttx/configs/stm32f3discovery/src/up_buttons.c
index 89d225b13..2a17919b9 100644
--- a/nuttx/configs/stm32f3discovery/src/up_buttons.c
+++ b/nuttx/configs/stm32f3discovery/src/up_buttons.c
@@ -79,7 +79,7 @@ static const uint16_t g_buttons[NUM_BUTTONS] =
* Description:
* board_button_initialize() must be called to initialize button resources. After
* that, board_buttons() may be called to collect the current state of all
* buttons or up_irqbutton() may be called to register button interrupt
* handlers.
*
****************************************************************************/
@@ -133,7 +133,7 @@ uint8_t board_buttons(void)
* Description:
* board_button_initialize() must be called to initialize button resources. After
* that, board_buttons() may be called to collect the current state of all
* buttons or up_irqbutton() may be called to register button interrupt
* handlers.
*
* After board_button_initialize() has been called, board_buttons() may be called to
@@ -141,7 +141,7 @@ uint8_t board_buttons(void)
* with each bit associated with a button. See the BUTTON_*_BIT
* definitions in board.h for the meaning of each bit.
*
* up_irqbutton() may be called to register an interrupt handler that will
* be called when a button is depressed or released. The ID value is a
* button enumeration value that uniquely identifies a button resource. See the
* BUTTON_* definitions in board.h for the meaning of enumeration
@@ -151,7 +151,7 @@ uint8_t board_buttons(void)
************************************************************************************/
#ifdef CONFIG_ARCH_IRQBUTTONS
-xcpt_t up_irqbutton(int id, xcpt_t irqhandler)
+xcpt_t board_button_irq(int id, xcpt_t irqhandler)
{
xcpt_t oldhandler = NULL;
@@ -79,7 +79,7 @@ static const uint16_t g_buttons[NUM_BUTTONS] =
* board_button_initialize() must be called to initialize button resources. After
* that, board_buttons() may be called to collect the current state of all
- * buttons or up_irqbutton() may be called to register button interrupt
+ * buttons or board_button_irq() may be called to register button interrupt
* handlers.
*
@@ -133,7 +133,7 @@ uint8_t board_buttons(void)
* board_button_initialize() must be called to initialize button resources. After
* that, board_buttons() may be called to collect the current state of all
- * buttons or up_irqbutton() may be called to register button interrupt
+ * buttons or board_button_irq() may be called to register button interrupt
* handlers.
*
@@ -141,7 +141,7 @@ uint8_t board_buttons(void)
* definitions in board.h for the meaning of each bit.
*
- * up_irqbutton() may be called to register an interrupt handler that will
+ * board_button_irq() may be called to register an interrupt handler that will
* be called when a button is depressed or released. The ID value is a
* button enumeration value that uniquely identifies a button resource. See the
diff --git a/nuttx/configs/stm32f429i-disco/src/up_buttons.c b/nuttx/configs/stm32f429i-disco/src/up_buttons.c
index 2718c0245..12eb45bb7 100644
--- a/nuttx/configs/stm32f429i-disco/src/up_buttons.c
+++ b/nuttx/configs/stm32f429i-disco/src/up_buttons.c
@@ -79,7 +79,7 @@ static const uint16_t g_buttons[NUM_BUTTONS] =
* Description:
* board_button_initialize() must be called to initialize button resources. After
* that, board_buttons() may be called to collect the current state of all
* buttons or up_irqbutton() may be called to register button interrupt
* handlers.
*
****************************************************************************/
@@ -133,7 +133,7 @@ uint8_t board_buttons(void)
* Description:
* board_button_initialize() must be called to initialize button resources. After
* that, board_buttons() may be called to collect the current state of all
* buttons or up_irqbutton() may be called to register button interrupt
* handlers.
*
* After board_button_initialize() has been called, board_buttons() may be called to
@@ -141,7 +141,7 @@ uint8_t board_buttons(void)
* with each bit associated with a button. See the BUTTON_*_BIT
* definitions in board.h for the meaning of each bit.
*
* up_irqbutton() may be called to register an interrupt handler that will
* be called when a button is depressed or released. The ID value is a
* button enumeration value that uniquely identifies a button resource. See the
* BUTTON_* definitions in board.h for the meaning of enumeration
@@ -151,7 +151,7 @@ uint8_t board_buttons(void)
************************************************************************************/
#ifdef CONFIG_ARCH_IRQBUTTONS
-xcpt_t up_irqbutton(int id, xcpt_t irqhandler)
+xcpt_t board_button_irq(int id, xcpt_t irqhandler)
{
xcpt_t oldhandler = NULL;
@@ -79,7 +79,7 @@ static const uint16_t g_buttons[NUM_BUTTONS] =
* board_button_initialize() must be called to initialize button resources. After
* that, board_buttons() may be called to collect the current state of all
- * buttons or up_irqbutton() may be called to register button interrupt
+ * buttons or board_button_irq() may be called to register button interrupt
* handlers.
*
@@ -133,7 +133,7 @@ uint8_t board_buttons(void)
* board_button_initialize() must be called to initialize button resources. After
* that, board_buttons() may be called to collect the current state of all
- * buttons or up_irqbutton() may be called to register button interrupt
+ * buttons or board_button_irq() may be called to register button interrupt
* handlers.
*
@@ -141,7 +141,7 @@ uint8_t board_buttons(void)
* definitions in board.h for the meaning of each bit.
*
- * up_irqbutton() may be called to register an interrupt handler that will
+ * board_button_irq() may be called to register an interrupt handler that will
* be called when a button is depressed or released. The ID value is a
* button enumeration value that uniquely identifies a button resource. See the
diff --git a/nuttx/configs/stm32f4discovery/src/up_buttons.c b/nuttx/configs/stm32f4discovery/src/up_buttons.c
index f9983291a..45ffbb236 100644
--- a/nuttx/configs/stm32f4discovery/src/up_buttons.c
+++ b/nuttx/configs/stm32f4discovery/src/up_buttons.c
@@ -79,7 +79,7 @@ static const uint16_t g_buttons[NUM_BUTTONS] =
* Description:
* board_button_initialize() must be called to initialize button resources. After
* that, board_buttons() may be called to collect the current state of all
* buttons or up_irqbutton() may be called to register button interrupt
* handlers.
*
****************************************************************************/
@@ -133,7 +133,7 @@ uint8_t board_buttons(void)
* Description:
* board_button_initialize() must be called to initialize button resources. After
* that, board_buttons() may be called to collect the current state of all
* buttons or up_irqbutton() may be called to register button interrupt
* handlers.
*
* After board_button_initialize() has been called, board_buttons() may be called to
@@ -141,7 +141,7 @@ uint8_t board_buttons(void)
* with each bit associated with a button. See the BUTTON_*_BIT
* definitions in board.h for the meaning of each bit.
*
* up_irqbutton() may be called to register an interrupt handler that will
* be called when a button is depressed or released. The ID value is a
* button enumeration value that uniquely identifies a button resource. See the
* BUTTON_* definitions in board.h for the meaning of enumeration
@@ -151,7 +151,7 @@ uint8_t board_buttons(void)
************************************************************************************/
#ifdef CONFIG_ARCH_IRQBUTTONS
-xcpt_t up_irqbutton(int id, xcpt_t irqhandler)
+xcpt_t board_button_irq(int id, xcpt_t irqhandler)
{
xcpt_t oldhandler = NULL;
@@ -79,7 +79,7 @@ static const uint16_t g_buttons[NUM_BUTTONS] =
* board_button_initialize() must be called to initialize button resources. After
* that, board_buttons() may be called to collect the current state of all
- * buttons or up_irqbutton() may be called to register button interrupt
+ * buttons or board_button_irq() may be called to register button interrupt
* handlers.
*
@@ -133,7 +133,7 @@ uint8_t board_buttons(void)
* board_button_initialize() must be called to initialize button resources. After
* that, board_buttons() may be called to collect the current state of all
- * buttons or up_irqbutton() may be called to register button interrupt
+ * buttons or board_button_irq() may be called to register button interrupt
* handlers.
*
@@ -141,7 +141,7 @@ uint8_t board_buttons(void)
* definitions in board.h for the meaning of each bit.
*
- * up_irqbutton() may be called to register an interrupt handler that will
+ * board_button_irq() may be called to register an interrupt handler that will
* be called when a button is depressed or released. The ID value is a
* button enumeration value that uniquely identifies a button resource. See the
diff --git a/nuttx/configs/stm32ldiscovery/src/stm32_buttons.c b/nuttx/configs/stm32ldiscovery/src/stm32_buttons.c
index 2d2cc8807..d50523700 100644
--- a/nuttx/configs/stm32ldiscovery/src/stm32_buttons.c
+++ b/nuttx/configs/stm32ldiscovery/src/stm32_buttons.c
@@ -79,7 +79,7 @@ static const uint16_t g_buttons[NUM_BUTTONS] =
* Description:
* board_button_initialize() must be called to initialize button resources. After
* that, board_buttons() may be called to collect the current state of all
* buttons or up_irqbutton() may be called to register button interrupt
* handlers.
*
****************************************************************************/
@@ -133,7 +133,7 @@ uint8_t board_buttons(void)
* Description:
* board_button_initialize() must be called to initialize button resources. After
* that, board_buttons() may be called to collect the current state of all
* buttons or up_irqbutton() may be called to register button interrupt
* handlers.
*
* After board_button_initialize() has been called, board_buttons() may be called to
@@ -141,7 +141,7 @@ uint8_t board_buttons(void)
* with each bit associated with a button. See the BUTTON_*_BIT
* definitions in board.h for the meaning of each bit.
*
* up_irqbutton() may be called to register an interrupt handler that will
* be called when a button is depressed or released. The ID value is a
* button enumeration value that uniquely identifies a button resource. See the
* BUTTON_* definitions in board.h for the meaning of enumeration
@@ -151,7 +151,7 @@ uint8_t board_buttons(void)
************************************************************************************/
#ifdef CONFIG_ARCH_IRQBUTTONS
-xcpt_t up_irqbutton(int id, xcpt_t irqhandler)
+xcpt_t board_button_irq(int id, xcpt_t irqhandler)
{
xcpt_t oldhandler = NULL;
@@ -79,7 +79,7 @@ static const uint16_t g_buttons[NUM_BUTTONS] =
* board_button_initialize() must be called to initialize button resources. After
* that, board_buttons() may be called to collect the current state of all
- * buttons or up_irqbutton() may be called to register button interrupt
+ * buttons or board_button_irq() may be called to register button interrupt
* handlers.
*
@@ -133,7 +133,7 @@ uint8_t board_buttons(void)
* board_button_initialize() must be called to initialize button resources. After
* that, board_buttons() may be called to collect the current state of all
- * buttons or up_irqbutton() may be called to register button interrupt
+ * buttons or board_button_irq() may be called to register button interrupt
* handlers.
*
@@ -141,7 +141,7 @@ uint8_t board_buttons(void)
* definitions in board.h for the meaning of each bit.
*
- * up_irqbutton() may be called to register an interrupt handler that will
+ * board_button_irq() may be called to register an interrupt handler that will
* be called when a button is depressed or released. The ID value is a
* button enumeration value that uniquely identifies a button resource. See the
diff --git a/nuttx/configs/stm32vldiscovery/src/stm32_buttons.c b/nuttx/configs/stm32vldiscovery/src/stm32_buttons.c
index 56599dba2..20c863572 100644
--- a/nuttx/configs/stm32vldiscovery/src/stm32_buttons.c
+++ b/nuttx/configs/stm32vldiscovery/src/stm32_buttons.c
@@ -59,7 +59,7 @@
* Description:
* board_button_initialize() must be called to initialize button resources. After
* that, board_buttons() may be called to collect the current state of all
* buttons or up_irqbutton() may be called to register button interrupt
* handlers.
*
****************************************************************************/
@@ -88,7 +88,7 @@ uint8_t board_buttons(void)
* Description:
* board_button_initialize() must be called to initialize button resources. After
* that, board_buttons() may be called to collect the current state of all
* buttons or up_irqbutton() may be called to register button interrupt
* handlers.
*
* After board_button_initialize() has been called, board_buttons() may be called to
@@ -96,7 +96,7 @@ uint8_t board_buttons(void)
* with each bit associated with a button. See the BUTTON_*_BIT and JOYSTICK_*_BIT
* definitions in board.h for the meaning of each bit.
*
* up_irqbutton() may be called to register an interrupt handler that will
* be called when a button is depressed or released. The ID value is a
* button enumeration value that uniquely identifies a button resource. See the
* BUTTON_* and JOYSTICK_* definitions in board.h for the meaning of enumeration
@@ -106,7 +106,7 @@ uint8_t board_buttons(void)
************************************************************************************/
#ifdef CONFIG_ARCH_IRQBUTTONS
-xcpt_t up_irqbutton(int id, xcpt_t irqhandler)
+xcpt_t board_button_irq(int id, xcpt_t irqhandler)
{
xcpt_t oldhandler = NULL;
@@ -59,7 +59,7 @@
* board_button_initialize() must be called to initialize button resources. After
* that, board_buttons() may be called to collect the current state of all
- * buttons or up_irqbutton() may be called to register button interrupt
+ * buttons or board_button_irq() may be called to register button interrupt
* handlers.
*
@@ -88,7 +88,7 @@ uint8_t board_buttons(void)
* board_button_initialize() must be called to initialize button resources. After
* that, board_buttons() may be called to collect the current state of all
- * buttons or up_irqbutton() may be called to register button interrupt
+ * buttons or board_button_irq() may be called to register button interrupt
* handlers.
*
@@ -96,7 +96,7 @@ uint8_t board_buttons(void)
* definitions in board.h for the meaning of each bit.
*
- * up_irqbutton() may be called to register an interrupt handler that will
+ * board_button_irq() may be called to register an interrupt handler that will
* be called when a button is depressed or released. The ID value is a
* button enumeration value that uniquely identifies a button resource. See the
diff --git a/nuttx/configs/sure-pic32mx/src/pic32mx_buttons.c b/nuttx/configs/sure-pic32mx/src/pic32mx_buttons.c
index 4d3dddeeb..b810fd488 100644
--- a/nuttx/configs/sure-pic32mx/src/pic32mx_buttons.c
+++ b/nuttx/configs/sure-pic32mx/src/pic32mx_buttons.c
@@ -130,7 +130,7 @@ static const uint8_t g_buttoncn[NUM_BUTTONS] =
* Description:
* board_button_initialize() must be called to initialize button resources. After
* that, board_buttons() may be called to collect the current state of all
* buttons or up_irqbutton() may be called to register button interrupt
* handlers.
*
****************************************************************************/
@@ -179,7 +179,7 @@ uint8_t board_buttons(void)
* Description:
* board_button_initialize() must be called to initialize button resources. After
* that, board_buttons() may be called to collect the current state of all
* buttons or up_irqbutton() may be called to register button interrupt
* handlers.
*
* After board_button_initialize() has been called, board_buttons() may be called to
@@ -187,7 +187,7 @@ uint8_t board_buttons(void)
* with each bit associated with a button. See the BUTTON_*_BIT and JOYSTICK_*_BIT
* definitions in board.h for the meaning of each bit.
*
* up_irqbutton() may be called to register an interrupt handler that will
* be called when a button is depressed or released. The ID value is a
* button enumeration value that uniquely identifies a button resource. See the
* BUTTON_* and JOYSTICK_* definitions in board.h for the meaning of enumeration
@@ -205,7 +205,7 @@ uint8_t board_buttons(void)
************************************************************************************/
#ifdef CONFIG_ARCH_IRQBUTTONS
-xcpt_t up_irqbutton(int id, xcpt_t irqhandler)
+xcpt_t board_button_irq(int id, xcpt_t irqhandler)
{
xcpt_t oldhandler = NULL;
@@ -130,7 +130,7 @@ static const uint8_t g_buttoncn[NUM_BUTTONS] =
* board_button_initialize() must be called to initialize button resources. After
* that, board_buttons() may be called to collect the current state of all
- * buttons or up_irqbutton() may be called to register button interrupt
+ * buttons or board_button_irq() may be called to register button interrupt
* handlers.
*
@@ -179,7 +179,7 @@ uint8_t board_buttons(void)
* board_button_initialize() must be called to initialize button resources. After
* that, board_buttons() may be called to collect the current state of all
- * buttons or up_irqbutton() may be called to register button interrupt
+ * buttons or board_button_irq() may be called to register button interrupt
* handlers.
*
@@ -187,7 +187,7 @@ uint8_t board_buttons(void)
* definitions in board.h for the meaning of each bit.
*
- * up_irqbutton() may be called to register an interrupt handler that will
+ * board_button_irq() may be called to register an interrupt handler that will
* be called when a button is depressed or released. The ID value is a
* button enumeration value that uniquely identifies a button resource. See the
diff --git a/nuttx/configs/twr-k60n512/src/up_buttons.c b/nuttx/configs/twr-k60n512/src/up_buttons.c
index b81d0ea53..4bd6b7adf 100644
--- a/nuttx/configs/twr-k60n512/src/up_buttons.c
+++ b/nuttx/configs/twr-k60n512/src/up_buttons.c
@@ -75,7 +75,7 @@
* Description:
* board_button_initialize() must be called to initialize button resources. After
* that, board_buttons() may be called to collect the current state of all
* buttons or up_irqbutton() may be called to register button interrupt
* handlers.
*
****************************************************************************/
@@ -115,7 +115,7 @@ uint8_t board_buttons(void)
* Description:
* board_button_initialize() must be called to initialize button resources. After
* that, board_buttons() may be called to collect the current state of all
* buttons or up_irqbutton() may be called to register button interrupt
* handlers.
*
* After board_button_initialize() has been called, board_buttons() may be called to
@@ -123,7 +123,7 @@ uint8_t board_buttons(void)
* with each bit associated with a button. See the BUTTON_*_BIT and JOYSTICK_*_BIT
* definitions in board.h for the meaning of each bit.
*
* up_irqbutton() may be called to register an interrupt handler that will
* be called when a button is depressed or released. The ID value is a
* button enumeration value that uniquely identifies a button resource. See the
* BUTTON_* and JOYSTICK_* definitions in board.h for the meaning of enumeration
@@ -133,7 +133,7 @@ uint8_t board_buttons(void)
************************************************************************************/
#ifdef CONFIG_ARCH_IRQBUTTONS
-xcpt_t up_irqbutton(int id, xcpt_t irqhandler)
+xcpt_t board_button_irq(int id, xcpt_t irqhandler)
{
xcpt_t oldhandler = NULL;
uint32_t pinset;
@@ -75,7 +75,7 @@
* board_button_initialize() must be called to initialize button resources. After
* that, board_buttons() may be called to collect the current state of all
- * buttons or up_irqbutton() may be called to register button interrupt
+ * buttons or board_button_irq() may be called to register button interrupt
* handlers.
*
@@ -115,7 +115,7 @@ uint8_t board_buttons(void)
* board_button_initialize() must be called to initialize button resources. After
* that, board_buttons() may be called to collect the current state of all
- * buttons or up_irqbutton() may be called to register button interrupt
+ * buttons or board_button_irq() may be called to register button interrupt
* handlers.
*
@@ -123,7 +123,7 @@ uint8_t board_buttons(void)
* definitions in board.h for the meaning of each bit.
*
- * up_irqbutton() may be called to register an interrupt handler that will
+ * board_button_irq() may be called to register an interrupt handler that will
* be called when a button is depressed or released. The ID value is a
* button enumeration value that uniquely identifies a button resource. See the
diff --git a/nuttx/configs/ubw32/src/up_buttons.c b/nuttx/configs/ubw32/src/up_buttons.c
index 39c53c4e3..9beede7cb 100644
--- a/nuttx/configs/ubw32/src/up_buttons.c
+++ b/nuttx/configs/ubw32/src/up_buttons.c
@@ -109,7 +109,7 @@ static const uint8_t g_buttoncn[NUM_BUTTONS] =
* Description:
* board_button_initialize() must be called to initialize button resources. After
* that, board_buttons() may be called to collect the current state of all
* buttons or up_irqbutton() may be called to register button interrupt
* handlers.
*
****************************************************************************/
@@ -154,7 +154,7 @@ uint8_t board_buttons(void)
* Description:
* board_button_initialize() must be called to initialize button resources. After
* that, board_buttons() may be called to collect the current state of all
* buttons or up_irqbutton() may be called to register button interrupt
* handlers.
*
* After board_button_initialize() has been called, board_buttons() may be called to
@@ -162,7 +162,7 @@ uint8_t board_buttons(void)
* with each bit associated with a button. See the BUTTON_*_BIT definitions in
* board.h for the meaning of each bit.
*
* up_irqbutton() may be called to register an interrupt handler that will
* be called when a button is depressed or released. The ID value is a
* button enumeration value that uniquely identifies a button resource. See the
* BUTTON_* definitions in board.h for the meaning of enumeration value. The
@@ -180,7 +180,7 @@ uint8_t board_buttons(void)
************************************************************************************/
#ifdef CONFIG_ARCH_IRQBUTTONS
-xcpt_t up_irqbutton(int id, xcpt_t irqhandler)
+xcpt_t board_button_irq(int id, xcpt_t irqhandler)
{
xcpt_t oldhandler = NULL;
@@ -109,7 +109,7 @@ static const uint8_t g_buttoncn[NUM_BUTTONS] =
* board_button_initialize() must be called to initialize button resources. After
* that, board_buttons() may be called to collect the current state of all
- * buttons or up_irqbutton() may be called to register button interrupt
+ * buttons or board_button_irq() may be called to register button interrupt
* handlers.
*
@@ -154,7 +154,7 @@ uint8_t board_buttons(void)
* board_button_initialize() must be called to initialize button resources. After
* that, board_buttons() may be called to collect the current state of all
- * buttons or up_irqbutton() may be called to register button interrupt
+ * buttons or board_button_irq() may be called to register button interrupt
* handlers.
*
@@ -162,7 +162,7 @@ uint8_t board_buttons(void)
* board.h for the meaning of each bit.
*
- * up_irqbutton() may be called to register an interrupt handler that will
+ * board_button_irq() may be called to register an interrupt handler that will
* be called when a button is depressed or released. The ID value is a
* button enumeration value that uniquely identifies a button resource. See the
diff --git a/nuttx/configs/viewtool-stm32f107/src/stm32_buttons.c b/nuttx/configs/viewtool-stm32f107/src/stm32_buttons.c
index 4e9261f36..542181069 100644
--- a/nuttx/configs/viewtool-stm32f107/src/stm32_buttons.c
+++ b/nuttx/configs/viewtool-stm32f107/src/stm32_buttons.c
@@ -78,7 +78,7 @@ static const uint16_t g_buttons[NUM_BUTTONS] =
* Description:
* board_button_initialize() must be called to initialize button resources. After
* that, board_buttons() may be called to collect the current state of all
* buttons or up_irqbutton() may be called to register button interrupt
* handlers.
*
****************************************************************************/
@@ -133,7 +133,7 @@ uint8_t board_buttons(void)
* Description:
* board_button_initialize() must be called to initialize button resources. After
* that, board_buttons() may be called to collect the current state of all
* buttons or up_irqbutton() may be called to register button interrupt
* handlers.
*
* After board_button_initialize() has been called, board_buttons() may be called to
@@ -141,7 +141,7 @@ uint8_t board_buttons(void)
* with each bit associated with a button. See the BUTTON_*_BIT and JOYSTICK_*_BIT
* definitions in board.h for the meaning of each bit.
*
* up_irqbutton() may be called to register an interrupt handler that will
* be called when a button is depressed or released. The ID value is a
* button enumeration value that uniquely identifies a button resource. See the
* BUTTON_* and JOYSTICK_* definitions in board.h for the meaning of enumeration
@@ -151,7 +151,7 @@ uint8_t board_buttons(void)
************************************************************************************/
#ifdef CONFIG_ARCH_IRQBUTTONS
-xcpt_t up_irqbutton(int id, xcpt_t irqhandler)
+xcpt_t board_button_irq(int id, xcpt_t irqhandler)
{
xcpt_t oldhandler = NULL;
@@ -78,7 +78,7 @@ static const uint16_t g_buttons[NUM_BUTTONS] =
* board_button_initialize() must be called to initialize button resources. After
* that, board_buttons() may be called to collect the current state of all
- * buttons or up_irqbutton() may be called to register button interrupt
+ * buttons or board_button_irq() may be called to register button interrupt
* handlers.
*
@@ -133,7 +133,7 @@ uint8_t board_buttons(void)
* board_button_initialize() must be called to initialize button resources. After
* that, board_buttons() may be called to collect the current state of all
- * buttons or up_irqbutton() may be called to register button interrupt
+ * buttons or board_button_irq() may be called to register button interrupt
* handlers.
*
@@ -141,7 +141,7 @@ uint8_t board_buttons(void)
* definitions in board.h for the meaning of each bit.
*
- * up_irqbutton() may be called to register an interrupt handler that will
+ * board_button_irq() may be called to register an interrupt handler that will
* be called when a button is depressed or released. The ID value is a
* button enumeration value that uniquely identifies a button resource. See the
diff --git a/nuttx/configs/zkit-arm-1769/src/up_buttons.c b/nuttx/configs/zkit-arm-1769/src/up_buttons.c
index dbfc2e1bb..90658428a 100644
--- a/nuttx/configs/zkit-arm-1769/src/up_buttons.c
+++ b/nuttx/configs/zkit-arm-1769/src/up_buttons.c
@@ -88,7 +88,7 @@ static xcpt_t g_oldhandler;
* Description:
* board_button_initialize() must be called to initialize button resources. After
* that, board_buttons() may be called to collect the current state of all
* buttons or up_irqbutton() may be called to register button interrupt
* handlers.
*
****************************************************************************/
@@ -140,7 +140,7 @@ uint8_t board_buttons(void)
* Description:
* board_button_initialize() must be called to initialize button resources. After
* that, board_buttons() may be called to collect the current state of all
* buttons or up_irqbutton() may be called to register button interrupt
* handlers.
*
* After board_button_initialize() has been called, board_buttons() may be called to
@@ -148,7 +148,7 @@ uint8_t board_buttons(void)
* with each bit associated with a button. See the BUTTON_*_BIT and JOYSTICK_*_BIT
* definitions in board.h for the meaning of each bit.
*
* up_irqbutton() may be called to register an interrupt handler that will
* be called when a button is depressed or released. The ID value is a
* button enumeration value that uniquely identifies a button resource. See the
* BUTTON_* and JOYSTICK_* definitions in board.h for the meaning of enumeration
@@ -158,7 +158,7 @@ uint8_t board_buttons(void)
************************************************************************************/
#if defined CONFIG_ARCH_IRQBUTTONS && CONFIG_GPIO_IRQ
-xcpt_t up_irqbutton(int id, xcpt_t irqhandler)
+xcpt_t board_button_irq(int id, xcpt_t irqhandler)
{
xcpt_t rethandler = NULL;
irqstate_t flags;
@@ -88,7 +88,7 @@ static xcpt_t g_oldhandler;
* board_button_initialize() must be called to initialize button resources. After
* that, board_buttons() may be called to collect the current state of all
- * buttons or up_irqbutton() may be called to register button interrupt
+ * buttons or board_button_irq() may be called to register button interrupt
* handlers.
*
@@ -140,7 +140,7 @@ uint8_t board_buttons(void)
* board_button_initialize() must be called to initialize button resources. After
* that, board_buttons() may be called to collect the current state of all
- * buttons or up_irqbutton() may be called to register button interrupt
+ * buttons or board_button_irq() may be called to register button interrupt
* handlers.
*
@@ -148,7 +148,7 @@ uint8_t board_buttons(void)
* definitions in board.h for the meaning of each bit.
*
- * up_irqbutton() may be called to register an interrupt handler that will
+ * board_button_irq() may be called to register an interrupt handler that will
* be called when a button is depressed or released. The ID value is a
* button enumeration value that uniquely identifies a button resource. See the
diff --git a/nuttx/include/nuttx/arch.h b/nuttx/include/nuttx/arch.h
index 42beee559..8a9047e80 100644
--- a/nuttx/include/nuttx/arch.h
+++ b/nuttx/include/nuttx/arch.h
@@ -1020,7 +1020,7 @@ ssize_t up_check_stack_remain(void);
* Description:
* board_button_initialize() must be called to initialize button resources.
* After that, board_buttons() may be called to collect the current state of
* all buttons or up_irqbutton() may be called to register button interrupt
* handlers.
*
* NOTE: This interface may or may not be supported by board-specific
@@ -1055,7 +1055,7 @@ uint8_t board_buttons(void);
#endif
/****************************************************************************
- * Name: up_irqbutton
+ * Name: board_button_irq
*
* Description:
* This function may be called to register an interrupt handler that will
@@ -1072,7 +1072,7 @@ uint8_t board_buttons(void);
****************************************************************************/
#ifdef CONFIG_ARCH_IRQBUTTONS
-xcpt_t up_irqbutton(int id, xcpt_t irqhandler);
+xcpt_t board_button_irq(int id, xcpt_t irqhandler);
#endif
/************************************************************************************
@@ -1020,7 +1020,7 @@ ssize_t up_check_stack_remain(void);
* board_button_initialize() must be called to initialize button resources.
* After that, board_buttons() may be called to collect the current state of
- * all buttons or up_irqbutton() may be called to register button interrupt
+ * all buttons or board_button_irq() may be called to register button interrupt
* handlers.
*